From 3bfdda366ab04221b3cf5ae1eb7b9b0a9f295017 Mon Sep 17 00:00:00 2001
From: Jean-Paul Smets <jp@nexedi.com>
Date: Sat, 7 Nov 2009 10:21:20 +0000
Subject: [PATCH] Quick comment of code before removal of the whole class.

git-svn-id: https://svn.erp5.org/repos/public/erp5/trunk@30384 20353a03-c40f-0410-a6d1-a30d3c3de9de
---
 product/ERP5/DivergenceSolutionDecision.py | 5 +++--
 1 file changed, 3 insertions(+), 2 deletions(-)

diff --git a/product/ERP5/DivergenceSolutionDecision.py b/product/ERP5/DivergenceSolutionDecision.py
index 9f01e0f1bd..ec7143ed8f 100644
--- a/product/ERP5/DivergenceSolutionDecision.py
+++ b/product/ERP5/DivergenceSolutionDecision.py
@@ -34,6 +34,7 @@ from Persistence import Persistent
 
 class DivergenceSolutionDecision(Persistent):
   """Decision class
+    XXX-JPS DivergenceResolutionDecision ?
 
     Represent decision took during solving divergence between reality and
     simulation
@@ -61,7 +62,7 @@ class DivergenceSolutionDecision(Persistent):
       string representing took decision:
         * accept
         * adopt
-        * split
+        * split[**** why noy solve JPS-XXX)
 
     delivery_solver_name
       delivery solver used during taking decision
@@ -73,7 +74,7 @@ class DivergenceSolutionDecision(Persistent):
       If set, property on decision overrides
 
     split_kw
       Dictionary passed to TargetSolver in case of splitting.
   """
   meta_type = "DivergenceSolutionDecision"
   security = ClassSecurityInfo()
@@ -73,7 +74,7 @@ class DivergenceSolutionDecision(Persistent):
 
     split_kw
-      Dictionary passed to TargetSolver in case of splitting.
+      Dictionary passed to TargetSolver in case of splitting. JPS-XXX why only for split
   """
   meta_type = "DivergenceSolutionDecision"
-- 
2.30.9